# himena-bio

[![PyPI - Version](https://img.shields.io/pypi/v/himena-bio.svg)](https://pypi.org/project/himena-bio)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/himena-bio.svg)](https://pypi.org/project/himena-bio)
[![codecov](https://codecov.io/gh/hanjinliu/himena-bio/graph/badge.svg?token=XS0WdfiSIh)](https://codecov.io/gh/hanjinliu/himena-bio)

-----

Plasmid editor and basic bioinformatic analysis in [`himena`](https://github.com/hanjinliu/himena).

![](images/window.png)

## Installation

```console
pip install himena-bio
himena <my-profile> --install himena-bio
```
